﻿using System;
using System.Collections.Generic;
using System.Collections.Specialized;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Infragistics.Controls.Grids;
using Infragistics.Olap;
using Infragistics.Olap.Data;
using Infragistics.Olap.FlatData;

namespace xamPivotGridKeyboardNavigation
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
            this.PivotGrid.DataSource.Measures.CollectionChanged += Measures_CollectionChanged;
            this.PivotGrid.CellEdited += PivotGrid_CellEdited_1;
        }

        private void PivotGrid_KeyDown_1(object sender, KeyEventArgs e)
        {
            if (e.Key == Key.Tab)
            {
                
                int nextIndexCell =  (sender as XamPivotGrid).ActiveCell.DataRow.Cells.IndexOf( (sender as XamPivotGrid).ActiveCell) + 1;
                if (nextIndexCell == (sender as XamPivotGrid).ActiveCell.DataRow.Cells.Count)
                {
                    int index = (sender as XamPivotGrid).DataRows.IndexOf((sender as XamPivotGrid).ActiveCell.DataRow) + 1;
                    if (index < (sender as XamPivotGrid).DataRows.Count)
                    {
                        (sender as XamPivotGrid).DataRows[index].Cells[0].IsActive = true;
                        (sender as XamPivotGrid).DataRows[index].Cells[0].IsSelected = true;
                    }
                }
                else
                {
                    (sender as XamPivotGrid).ActiveCell.DataRow.Cells[nextIndexCell].IsActive = true;
                    (sender as XamPivotGrid).ActiveCell.DataRow.Cells[nextIndexCell].IsSelected = true;
                }
             
            }
        }

        private void PivotGrid_CellEdited_1(object sender, Infragistics.Controls.Grids.PivotCellEditedEventArgs e)
        {

            double newValue;
            Double.TryParse(e.EditedValue.ToString(), out newValue);

            List<int> indexes = ((FlatDataSource)this.PivotGrid.DataSource).GetCellItemsIndexes(e.Cell.Data as ICell);

            if (e.Measure.Caption == "NumberOfUnits")
            {
                Sale obj;
                foreach (int index in indexes)
                {
                    obj = ((FlatDataSource)this.PivotGrid.DataSource).GetRecord(index) as Sale;
                    obj.NumberOfUnits = 0;
                }
                obj = ((FlatDataSource)this.PivotGrid.DataSource).GetRecord(indexes[0]) as Sale;
                obj.NumberOfUnits = (int)newValue;
            }
            else
            {
                foreach (int index in indexes)
                {
                    Sale obj = ((FlatDataSource)this.PivotGrid.DataSource).GetRecord(index) as Sale;
                    obj.UnitPrice = newValue;
                }
            }

            this.PivotGrid.DataSource.RefreshGrid();
        }


        private void Measures_CollectionChanged(object sender, NotifyCollectionChangedEventArgs e)
        {
            switch (e.Action)
            {
                case NotifyCollectionChangedAction.Add:
                    foreach (IMeasureViewModel mvm in e.NewItems)
                    {
                        if (mvm.Caption != "AmountOfSale")
                            this.PivotGrid.EditSettings.EditableMeasures.Add(mvm.Measure);

                        if (mvm.Caption == "UnitPrice")
                        {
                            this.PivotGrid.DataSource.SetMeasureAggregator(
                                (IMeasureViewModel)mvm,
                                AggregationHelper.GetDefaultAverageAggregator(typeof(double))
                            );
                        }
                    }
                    break;

                case NotifyCollectionChangedAction.Remove:
                    foreach (IMeasureViewModel mvm in e.OldItems)
                    {
                        this.PivotGrid.EditSettings.EditableMeasures.Remove(mvm.Measure);
                    }

                    break;
            }
        }


     
    }
}
